from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Payments
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
class IPaymentAddress(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentAddress'
    _iid_ = Guid('{5f2264e9-6f3a-4166-a018-0a0b06bb32b5}')
    @winrt_commethod(6)
    def get_Country(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Country(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_AddressLines(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(9)
    def put_AddressLines(self, value: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]) -> Void: ...
    @winrt_commethod(10)
    def get_Region(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_Region(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_City(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_City(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_DependentLocality(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_DependentLocality(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_PostalCode(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def put_PostalCode(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(18)
    def get_SortingCode(self) -> WinRT_String: ...
    @winrt_commethod(19)
    def put_SortingCode(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(20)
    def get_LanguageCode(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_LanguageCode(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_Organization(self) -> WinRT_String: ...
    @winrt_commethod(23)
    def put_Organization(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(24)
    def get_Recipient(self) -> WinRT_String: ...
    @winrt_commethod(25)
    def put_Recipient(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(26)
    def get_PhoneNumber(self) -> WinRT_String: ...
    @winrt_commethod(27)
    def put_PhoneNumber(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(28)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    AddressLines = property(get_AddressLines, put_AddressLines)
    City = property(get_City, put_City)
    Country = property(get_Country, put_Country)
    DependentLocality = property(get_DependentLocality, put_DependentLocality)
    LanguageCode = property(get_LanguageCode, put_LanguageCode)
    Organization = property(get_Organization, put_Organization)
    PhoneNumber = property(get_PhoneNumber, put_PhoneNumber)
    PostalCode = property(get_PostalCode, put_PostalCode)
    Properties = property(get_Properties, None)
    Recipient = property(get_Recipient, put_Recipient)
    Region = property(get_Region, put_Region)
    SortingCode = property(get_SortingCode, put_SortingCode)
class IPaymentCanMakePaymentResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentCanMakePaymentResult'
    _iid_ = Guid('{7696fe55-d5d3-4d3d-b345-45591759c510}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.ApplicationModel.Payments.PaymentCanMakePaymentResultStatus: ...
    Status = property(get_Status, None)
class IPaymentCanMakePaymentResultFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentCanMakePaymentResultFactory'
    _iid_ = Guid('{bbdcaa3e-7d49-4f69-aa53-2a0f8164b7c9}')
    @winrt_commethod(6)
    def Create(self, value: win32more.Windows.ApplicationModel.Payments.PaymentCanMakePaymentResultStatus) -> win32more.Windows.ApplicationModel.Payments.PaymentCanMakePaymentResult: ...
class IPaymentCurrencyAmount(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentCurrencyAmount'
    _iid_ = Guid('{e3a3e9e0-b41f-4987-bdcb-071331f2daa4}')
    @winrt_commethod(6)
    def get_Currency(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Currency(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_CurrencySystem(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_CurrencySystem(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_Value(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_Value(self, value: WinRT_String) -> Void: ...
    Currency = property(get_Currency, put_Currency)
    CurrencySystem = property(get_CurrencySystem, put_CurrencySystem)
    Value = property(get_Value, put_Value)
class IPaymentCurrencyAmountFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentCurrencyAmountFactory'
    _iid_ = Guid('{3257d338-140c-4575-8535-f773178c09a7}')
    @winrt_commethod(6)
    def Create(self, value: WinRT_String, currency: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount: ...
    @winrt_commethod(7)
    def CreateWithCurrencySystem(self, value: WinRT_String, currency: WinRT_String, currencySystem: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount: ...
class IPaymentDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentDetails'
    _iid_ = Guid('{53bb2d7d-e0eb-4053-8eae-ce7c48e02945}')
    @winrt_commethod(6)
    def get_Total(self) -> win32more.Windows.ApplicationModel.Payments.PaymentItem: ...
    @winrt_commethod(7)
    def put_Total(self, value: win32more.Windows.ApplicationModel.Payments.PaymentItem) -> Void: ...
    @winrt_commethod(8)
    def get_DisplayItems(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentItem]: ...
    @winrt_commethod(9)
    def put_DisplayItems(self, value: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentItem]) -> Void: ...
    @winrt_commethod(10)
    def get_ShippingOptions(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentShippingOption]: ...
    @winrt_commethod(11)
    def put_ShippingOptions(self, value: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentShippingOption]) -> Void: ...
    @winrt_commethod(12)
    def get_Modifiers(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier]: ...
    @winrt_commethod(13)
    def put_Modifiers(self, value: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier]) -> Void: ...
    DisplayItems = property(get_DisplayItems, put_DisplayItems)
    Modifiers = property(get_Modifiers, put_Modifiers)
    ShippingOptions = property(get_ShippingOptions, put_ShippingOptions)
    Total = property(get_Total, put_Total)
class IPaymentDetailsFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentDetailsFactory'
    _iid_ = Guid('{cfe8afee-c0ea-4ca1-8bc7-6de67b1f3763}')
    @winrt_commethod(6)
    def Create(self, total: win32more.Windows.ApplicationModel.Payments.PaymentItem) -> win32more.Windows.ApplicationModel.Payments.PaymentDetails: ...
    @winrt_commethod(7)
    def CreateWithDisplayItems(self, total: win32more.Windows.ApplicationModel.Payments.PaymentItem, displayItems: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentItem]) -> win32more.Windows.ApplicationModel.Payments.PaymentDetails: ...
class IPaymentDetailsModifier(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentDetailsModifier'
    _iid_ = Guid('{be1c7d65-4323-41d7-b305-dfcb765f69de}')
    @winrt_commethod(6)
    def get_JsonData(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_SupportedMethodIds(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(8)
    def get_Total(self) -> win32more.Windows.ApplicationModel.Payments.PaymentItem: ...
    @winrt_commethod(9)
    def get_AdditionalDisplayItems(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentItem]: ...
    AdditionalDisplayItems = property(get_AdditionalDisplayItems, None)
    JsonData = property(get_JsonData, None)
    SupportedMethodIds = property(get_SupportedMethodIds, None)
    Total = property(get_Total, None)
class IPaymentDetailsModifierFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentDetailsModifierFactory'
    _iid_ = Guid('{79005286-54de-429c-9e4f-5dce6e10ebce}')
    @winrt_commethod(6)
    def Create(self, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], total: win32more.Windows.ApplicationModel.Payments.PaymentItem) -> win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier: ...
    @winrt_commethod(7)
    def CreateWithAdditionalDisplayItems(self, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], total: win32more.Windows.ApplicationModel.Payments.PaymentItem, additionalDisplayItems: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentItem]) -> win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier: ...
    @winrt_commethod(8)
    def CreateWithAdditionalDisplayItemsAndJsonData(self, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], total: win32more.Windows.ApplicationModel.Payments.PaymentItem, additionalDisplayItems: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentItem], jsonData: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier: ...
class IPaymentItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentItem'
    _iid_ = Guid('{685ac88b-79b2-4b76-9e03-a876223dfe72}')
    @winrt_commethod(6)
    def get_Label(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Label(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Amount(self) -> win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount: ...
    @winrt_commethod(9)
    def put_Amount(self, value: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount) -> Void: ...
    @winrt_commethod(10)
    def get_Pending(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_Pending(self, value: Boolean) -> Void: ...
    Amount = property(get_Amount, put_Amount)
    Label = property(get_Label, put_Label)
    Pending = property(get_Pending, put_Pending)
class IPaymentItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentItemFactory'
    _iid_ = Guid('{c6ab7ad8-2503-4d1d-a778-02b2e5927b2c}')
    @winrt_commethod(6)
    def Create(self, label: WinRT_String, amount: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount) -> win32more.Windows.ApplicationModel.Payments.PaymentItem: ...
class IPaymentMediator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentMediator'
    _iid_ = Guid('{fb0ee829-ec0c-449a-83da-7ae3073365a2}')
    @winrt_commethod(6)
    def GetSupportedMethodIdsAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_commethod(7)
    def SubmitPaymentRequestAsync(self, paymentRequest: win32more.Windows.ApplicationModel.Payments.PaymentRequest) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Payments.PaymentRequestSubmitResult]: ...
    @winrt_commethod(8)
    def SubmitPaymentRequestWithChangeHandlerAsync(self, paymentRequest: win32more.Windows.ApplicationModel.Payments.PaymentRequest, changeHandler: win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedHandler) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Payments.PaymentRequestSubmitResult]: ...
class IPaymentMediator2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentMediator2'
    _iid_ = Guid('{ceef98f1-e407-4128-8e73-d93d5f822786}')
    @winrt_commethod(6)
    def CanMakePaymentAsync(self, paymentRequest: win32more.Windows.ApplicationModel.Payments.PaymentRequest) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Payments.PaymentCanMakePaymentResult]: ...
class IPaymentMerchantInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentMerchantInfo'
    _iid_ = Guid('{63445050-0e94-4ed6-aacb-e6012bd327a7}')
    @winrt_commethod(6)
    def get_PackageFullName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    PackageFullName = property(get_PackageFullName, None)
    Uri = property(get_Uri, None)
class IPaymentMerchantInfoFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentMerchantInfoFactory'
    _iid_ = Guid('{9e89ced3-ccb7-4167-a8ec-e10ae96dbcd1}')
    @winrt_commethod(6)
    def Create(self, uri: win32more.Windows.Foundation.Uri) -> win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo: ...
class IPaymentMethodData(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentMethodData'
    _iid_ = Guid('{d1d3caf4-de98-4129-b1b7-c3ad86237bf4}')
    @winrt_commethod(6)
    def get_SupportedMethodIds(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(7)
    def get_JsonData(self) -> WinRT_String: ...
    JsonData = property(get_JsonData, None)
    SupportedMethodIds = property(get_SupportedMethodIds, None)
class IPaymentMethodDataFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentMethodDataFactory'
    _iid_ = Guid('{8addd27f-9baa-4a82-8342-a8210992a36b}')
    @winrt_commethod(6)
    def Create(self, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.ApplicationModel.Payments.PaymentMethodData: ...
    @winrt_commethod(7)
    def CreateWithJsonData(self, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], jsonData: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentMethodData: ...
class IPaymentOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentOptions'
    _iid_ = Guid('{aaa30854-1f2b-4365-8251-01b58915a5bc}')
    @winrt_commethod(6)
    def get_RequestPayerEmail(self) -> win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence: ...
    @winrt_commethod(7)
    def put_RequestPayerEmail(self, value: win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence) -> Void: ...
    @winrt_commethod(8)
    def get_RequestPayerName(self) -> win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence: ...
    @winrt_commethod(9)
    def put_RequestPayerName(self, value: win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence) -> Void: ...
    @winrt_commethod(10)
    def get_RequestPayerPhoneNumber(self) -> win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence: ...
    @winrt_commethod(11)
    def put_RequestPayerPhoneNumber(self, value: win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence) -> Void: ...
    @winrt_commethod(12)
    def get_RequestShipping(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_RequestShipping(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_ShippingType(self) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingType: ...
    @winrt_commethod(15)
    def put_ShippingType(self, value: win32more.Windows.ApplicationModel.Payments.PaymentShippingType) -> Void: ...
    RequestPayerEmail = property(get_RequestPayerEmail, put_RequestPayerEmail)
    RequestPayerName = property(get_RequestPayerName, put_RequestPayerName)
    RequestPayerPhoneNumber = property(get_RequestPayerPhoneNumber, put_RequestPayerPhoneNumber)
    RequestShipping = property(get_RequestShipping, put_RequestShipping)
    ShippingType = property(get_ShippingType, put_ShippingType)
class IPaymentRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentRequest'
    _iid_ = Guid('{b74942e1-ed7b-47eb-bc08-78cc5d6896b6}')
    @winrt_commethod(6)
    def get_MerchantInfo(self) -> win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo: ...
    @winrt_commethod(7)
    def get_Details(self) -> win32more.Windows.ApplicationModel.Payments.PaymentDetails: ...
    @winrt_commethod(8)
    def get_MethodData(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentMethodData]: ...
    @winrt_commethod(9)
    def get_Options(self) -> win32more.Windows.ApplicationModel.Payments.PaymentOptions: ...
    Details = property(get_Details, None)
    MerchantInfo = property(get_MerchantInfo, None)
    MethodData = property(get_MethodData, None)
    Options = property(get_Options, None)
class IPaymentRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentRequest2'
    _iid_ = Guid('{b63ccfb5-5998-493e-a04c-67048a50f141}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    Id = property(get_Id, None)
class IPaymentRequestChangedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentRequestChangedArgs'
    _iid_ = Guid('{c6145e44-cd8b-4be4-b555-27c99194c0c5}')
    @winrt_commethod(6)
    def get_ChangeKind(self) -> win32more.Windows.ApplicationModel.Payments.PaymentRequestChangeKind: ...
    @winrt_commethod(7)
    def get_ShippingAddress(self) -> win32more.Windows.ApplicationModel.Payments.PaymentAddress: ...
    @winrt_commethod(8)
    def get_SelectedShippingOption(self) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
    @winrt_commethod(9)
    def Acknowledge(self, changeResult: win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedResult) -> Void: ...
    ChangeKind = property(get_ChangeKind, None)
    SelectedShippingOption = property(get_SelectedShippingOption, None)
    ShippingAddress = property(get_ShippingAddress, None)
class IPaymentRequestChangedResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentRequestChangedResult'
    _iid_ = Guid('{df699e5c-16c4-47ad-9401-8440ec0757db}')
    @winrt_commethod(6)
    def get_ChangeAcceptedByMerchant(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_ChangeAcceptedByMerchant(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Message(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Message(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_UpdatedPaymentDetails(self) -> win32more.Windows.ApplicationModel.Payments.PaymentDetails: ...
    @winrt_commethod(11)
    def put_UpdatedPaymentDetails(self, value: win32more.Windows.ApplicationModel.Payments.PaymentDetails) -> Void: ...
    ChangeAcceptedByMerchant = property(get_ChangeAcceptedByMerchant, put_ChangeAcceptedByMerchant)
    Message = property(get_Message, put_Message)
    UpdatedPaymentDetails = property(get_UpdatedPaymentDetails, put_UpdatedPaymentDetails)
class IPaymentRequestChangedResultFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentRequestChangedResultFactory'
    _iid_ = Guid('{08740f56-1d33-4431-814b-67ea24bf21db}')
    @winrt_commethod(6)
    def Create(self, changeAcceptedByMerchant: Boolean) -> win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedResult: ...
    @winrt_commethod(7)
    def CreateWithPaymentDetails(self, changeAcceptedByMerchant: Boolean, updatedPaymentDetails: win32more.Windows.ApplicationModel.Payments.PaymentDetails) -> win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedResult: ...
class IPaymentRequestFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentRequestFactory'
    _iid_ = Guid('{3e8a79dc-6b74-42d3-b103-f0de35fb1848}')
    @winrt_commethod(6)
    def Create(self, details: win32more.Windows.ApplicationModel.Payments.PaymentDetails, methodData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentMethodData]) -> win32more.Windows.ApplicationModel.Payments.PaymentRequest: ...
    @winrt_commethod(7)
    def CreateWithMerchantInfo(self, details: win32more.Windows.ApplicationModel.Payments.PaymentDetails, methodData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentMethodData], merchantInfo: win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo) -> win32more.Windows.ApplicationModel.Payments.PaymentRequest: ...
    @winrt_commethod(8)
    def CreateWithMerchantInfoAndOptions(self, details: win32more.Windows.ApplicationModel.Payments.PaymentDetails, methodData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentMethodData], merchantInfo: win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo, options: win32more.Windows.ApplicationModel.Payments.PaymentOptions) -> win32more.Windows.ApplicationModel.Payments.PaymentRequest: ...
class IPaymentRequestFactory2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentRequestFactory2'
    _iid_ = Guid('{e6ce1325-a506-4372-b7ef-1a031d5662d1}')
    @winrt_commethod(6)
    def CreateWithMerchantInfoOptionsAndId(self, details: win32more.Windows.ApplicationModel.Payments.PaymentDetails, methodData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentMethodData], merchantInfo: win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo, options: win32more.Windows.ApplicationModel.Payments.PaymentOptions, id: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentRequest: ...
class IPaymentRequestSubmitResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentRequestSubmitResult'
    _iid_ = Guid('{7b9c3912-30f2-4e90-b249-8ce7d78ffe56}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.ApplicationModel.Payments.PaymentRequestStatus: ...
    @winrt_commethod(7)
    def get_Response(self) -> win32more.Windows.ApplicationModel.Payments.PaymentResponse: ...
    Response = property(get_Response, None)
    Status = property(get_Status, None)
class IPaymentResponse(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentResponse'
    _iid_ = Guid('{e1389457-8bd2-4888-9fa8-97985545108e}')
    @winrt_commethod(6)
    def get_PaymentToken(self) -> win32more.Windows.ApplicationModel.Payments.PaymentToken: ...
    @winrt_commethod(7)
    def get_ShippingOption(self) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
    @winrt_commethod(8)
    def get_ShippingAddress(self) -> win32more.Windows.ApplicationModel.Payments.PaymentAddress: ...
    @winrt_commethod(9)
    def get_PayerEmail(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_PayerName(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_PayerPhoneNumber(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def CompleteAsync(self, status: win32more.Windows.ApplicationModel.Payments.PaymentRequestCompletionStatus) -> win32more.Windows.Foundation.IAsyncAction: ...
    PayerEmail = property(get_PayerEmail, None)
    PayerName = property(get_PayerName, None)
    PayerPhoneNumber = property(get_PayerPhoneNumber, None)
    PaymentToken = property(get_PaymentToken, None)
    ShippingAddress = property(get_ShippingAddress, None)
    ShippingOption = property(get_ShippingOption, None)
class IPaymentShippingOption(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentShippingOption'
    _iid_ = Guid('{13372ada-9753-4574-8966-93145a76c7f9}')
    @winrt_commethod(6)
    def get_Label(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Label(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Amount(self) -> win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount: ...
    @winrt_commethod(9)
    def put_Amount(self, value: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount) -> Void: ...
    @winrt_commethod(10)
    def get_Tag(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_Tag(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_IsSelected(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsSelected(self, value: Boolean) -> Void: ...
    Amount = property(get_Amount, put_Amount)
    IsSelected = property(get_IsSelected, put_IsSelected)
    Label = property(get_Label, put_Label)
    Tag = property(get_Tag, put_Tag)
class IPaymentShippingOptionFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentShippingOptionFactory'
    _iid_ = Guid('{5de5f917-b2d7-446b-9d73-6123fbca3bc6}')
    @winrt_commethod(6)
    def Create(self, label: WinRT_String, amount: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
    @winrt_commethod(7)
    def CreateWithSelected(self, label: WinRT_String, amount: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount, selected: Boolean) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
    @winrt_commethod(8)
    def CreateWithSelectedAndTag(self, label: WinRT_String, amount: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount, selected: Boolean, tag: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
class IPaymentToken(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentToken'
    _iid_ = Guid('{bbcac013-ccd0-41f2-b2a1-0a2e4b5dce25}')
    @winrt_commethod(6)
    def get_PaymentMethodId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_JsonDetails(self) -> WinRT_String: ...
    JsonDetails = property(get_JsonDetails, None)
    PaymentMethodId = property(get_PaymentMethodId, None)
class IPaymentTokenFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Payments.IPaymentTokenFactory'
    _iid_ = Guid('{988cd7aa-4753-4904-8373-dd7b08b995c1}')
    @winrt_commethod(6)
    def Create(self, paymentMethodId: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentToken: ...
    @winrt_commethod(7)
    def CreateWithJsonDetails(self, paymentMethodId: WinRT_String, jsonDetails: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentToken: ...
class PaymentAddress(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentAddress
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentAddress'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentAddress.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Payments.PaymentAddress: ...
    @winrt_mixinmethod
    def get_Country(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Country(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_AddressLines(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def put_AddressLines(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]) -> Void: ...
    @winrt_mixinmethod
    def get_Region(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Region(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_City(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_City(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DependentLocality(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DependentLocality(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PostalCode(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PostalCode(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SortingCode(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SortingCode(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_LanguageCode(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_LanguageCode(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Organization(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Organization(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Recipient(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Recipient(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PhoneNumber(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PhoneNumber(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.ApplicationModel.Payments.IPaymentAddress) -> win32more.Windows.Foundation.Collections.ValueSet: ...
    AddressLines = property(get_AddressLines, put_AddressLines)
    City = property(get_City, put_City)
    Country = property(get_Country, put_Country)
    DependentLocality = property(get_DependentLocality, put_DependentLocality)
    LanguageCode = property(get_LanguageCode, put_LanguageCode)
    Organization = property(get_Organization, put_Organization)
    PhoneNumber = property(get_PhoneNumber, put_PhoneNumber)
    PostalCode = property(get_PostalCode, put_PostalCode)
    Properties = property(get_Properties, None)
    Recipient = property(get_Recipient, put_Recipient)
    Region = property(get_Region, put_Region)
    SortingCode = property(get_SortingCode, put_SortingCode)
class PaymentCanMakePaymentResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentCanMakePaymentResult
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentCanMakePaymentResult'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentCanMakePaymentResult.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentCanMakePaymentResultFactory, value: win32more.Windows.ApplicationModel.Payments.PaymentCanMakePaymentResultStatus) -> win32more.Windows.ApplicationModel.Payments.PaymentCanMakePaymentResult: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.ApplicationModel.Payments.IPaymentCanMakePaymentResult) -> win32more.Windows.ApplicationModel.Payments.PaymentCanMakePaymentResultStatus: ...
    Status = property(get_Status, None)
class PaymentCanMakePaymentResultStatus(Enum, Int32):
    Unknown = 0
    Yes = 1
    No = 2
    NotAllowed = 3
    UserNotSignedIn = 4
    SpecifiedPaymentMethodIdsNotSupported = 5
    NoQualifyingCardOnFile = 6
class PaymentCurrencyAmount(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentCurrencyAmount
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentCurrencyAmount'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount.Create(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount.CreateWithCurrencySystem(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentCurrencyAmountFactory, value: WinRT_String, currency: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount: ...
    @winrt_factorymethod
    def CreateWithCurrencySystem(cls: win32more.Windows.ApplicationModel.Payments.IPaymentCurrencyAmountFactory, value: WinRT_String, currency: WinRT_String, currencySystem: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount: ...
    @winrt_mixinmethod
    def get_Currency(self: win32more.Windows.ApplicationModel.Payments.IPaymentCurrencyAmount) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Currency(self: win32more.Windows.ApplicationModel.Payments.IPaymentCurrencyAmount, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_CurrencySystem(self: win32more.Windows.ApplicationModel.Payments.IPaymentCurrencyAmount) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CurrencySystem(self: win32more.Windows.ApplicationModel.Payments.IPaymentCurrencyAmount, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.ApplicationModel.Payments.IPaymentCurrencyAmount) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.ApplicationModel.Payments.IPaymentCurrencyAmount, value: WinRT_String) -> Void: ...
    Currency = property(get_Currency, put_Currency)
    CurrencySystem = property(get_CurrencySystem, put_CurrencySystem)
    Value = property(get_Value, put_Value)
class PaymentDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentDetails
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentDetails'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentDetails.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentDetails.Create(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentDetails.CreateWithDisplayItems(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Payments.PaymentDetails: ...
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsFactory, total: win32more.Windows.ApplicationModel.Payments.PaymentItem) -> win32more.Windows.ApplicationModel.Payments.PaymentDetails: ...
    @winrt_factorymethod
    def CreateWithDisplayItems(cls: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsFactory, total: win32more.Windows.ApplicationModel.Payments.PaymentItem, displayItems: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentItem]) -> win32more.Windows.ApplicationModel.Payments.PaymentDetails: ...
    @winrt_mixinmethod
    def get_Total(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetails) -> win32more.Windows.ApplicationModel.Payments.PaymentItem: ...
    @winrt_mixinmethod
    def put_Total(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetails, value: win32more.Windows.ApplicationModel.Payments.PaymentItem) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayItems(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentItem]: ...
    @winrt_mixinmethod
    def put_DisplayItems(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetails, value: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentItem]) -> Void: ...
    @winrt_mixinmethod
    def get_ShippingOptions(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentShippingOption]: ...
    @winrt_mixinmethod
    def put_ShippingOptions(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetails, value: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentShippingOption]) -> Void: ...
    @winrt_mixinmethod
    def get_Modifiers(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetails) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier]: ...
    @winrt_mixinmethod
    def put_Modifiers(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetails, value: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier]) -> Void: ...
    DisplayItems = property(get_DisplayItems, put_DisplayItems)
    Modifiers = property(get_Modifiers, put_Modifiers)
    ShippingOptions = property(get_ShippingOptions, put_ShippingOptions)
    Total = property(get_Total, put_Total)
class PaymentDetailsModifier(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsModifier
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentDetailsModifier'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier.Create(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier.CreateWithAdditionalDisplayItems(*args))
        elif len(args) == 4:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier.CreateWithAdditionalDisplayItemsAndJsonData(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsModifierFactory, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], total: win32more.Windows.ApplicationModel.Payments.PaymentItem) -> win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier: ...
    @winrt_factorymethod
    def CreateWithAdditionalDisplayItems(cls: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsModifierFactory, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], total: win32more.Windows.ApplicationModel.Payments.PaymentItem, additionalDisplayItems: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentItem]) -> win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier: ...
    @winrt_factorymethod
    def CreateWithAdditionalDisplayItemsAndJsonData(cls: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsModifierFactory, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], total: win32more.Windows.ApplicationModel.Payments.PaymentItem, additionalDisplayItems: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentItem], jsonData: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentDetailsModifier: ...
    @winrt_mixinmethod
    def get_JsonData(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsModifier) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SupportedMethodIds(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsModifier) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_Total(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsModifier) -> win32more.Windows.ApplicationModel.Payments.PaymentItem: ...
    @winrt_mixinmethod
    def get_AdditionalDisplayItems(self: win32more.Windows.ApplicationModel.Payments.IPaymentDetailsModifier) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentItem]: ...
    AdditionalDisplayItems = property(get_AdditionalDisplayItems, None)
    JsonData = property(get_JsonData, None)
    SupportedMethodIds = property(get_SupportedMethodIds, None)
    Total = property(get_Total, None)
class PaymentItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentItem
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentItem.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentItemFactory, label: WinRT_String, amount: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount) -> win32more.Windows.ApplicationModel.Payments.PaymentItem: ...
    @winrt_mixinmethod
    def get_Label(self: win32more.Windows.ApplicationModel.Payments.IPaymentItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Label(self: win32more.Windows.ApplicationModel.Payments.IPaymentItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Amount(self: win32more.Windows.ApplicationModel.Payments.IPaymentItem) -> win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount: ...
    @winrt_mixinmethod
    def put_Amount(self: win32more.Windows.ApplicationModel.Payments.IPaymentItem, value: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount) -> Void: ...
    @winrt_mixinmethod
    def get_Pending(self: win32more.Windows.ApplicationModel.Payments.IPaymentItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_Pending(self: win32more.Windows.ApplicationModel.Payments.IPaymentItem, value: Boolean) -> Void: ...
    Amount = property(get_Amount, put_Amount)
    Label = property(get_Label, put_Label)
    Pending = property(get_Pending, put_Pending)
class PaymentMediator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentMediator
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentMediator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentMediator.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Payments.PaymentMediator: ...
    @winrt_mixinmethod
    def GetSupportedMethodIdsAsync(self: win32more.Windows.ApplicationModel.Payments.IPaymentMediator) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]]: ...
    @winrt_mixinmethod
    def SubmitPaymentRequestAsync(self: win32more.Windows.ApplicationModel.Payments.IPaymentMediator, paymentRequest: win32more.Windows.ApplicationModel.Payments.PaymentRequest) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Payments.PaymentRequestSubmitResult]: ...
    @winrt_mixinmethod
    def SubmitPaymentRequestWithChangeHandlerAsync(self: win32more.Windows.ApplicationModel.Payments.IPaymentMediator, paymentRequest: win32more.Windows.ApplicationModel.Payments.PaymentRequest, changeHandler: win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedHandler) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Payments.PaymentRequestSubmitResult]: ...
    @winrt_mixinmethod
    def CanMakePaymentAsync(self: win32more.Windows.ApplicationModel.Payments.IPaymentMediator2, paymentRequest: win32more.Windows.ApplicationModel.Payments.PaymentRequest) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Payments.PaymentCanMakePaymentResult]: ...
class PaymentMerchantInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentMerchantInfo
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentMerchantInfo'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo: ...
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentMerchantInfoFactory, uri: win32more.Windows.Foundation.Uri) -> win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo: ...
    @winrt_mixinmethod
    def get_PackageFullName(self: win32more.Windows.ApplicationModel.Payments.IPaymentMerchantInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.ApplicationModel.Payments.IPaymentMerchantInfo) -> win32more.Windows.Foundation.Uri: ...
    PackageFullName = property(get_PackageFullName, None)
    Uri = property(get_Uri, None)
class PaymentMethodData(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentMethodData
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentMethodData'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentMethodData.Create(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentMethodData.CreateWithJsonData(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentMethodDataFactory, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.ApplicationModel.Payments.PaymentMethodData: ...
    @winrt_factorymethod
    def CreateWithJsonData(cls: win32more.Windows.ApplicationModel.Payments.IPaymentMethodDataFactory, supportedMethodIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], jsonData: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentMethodData: ...
    @winrt_mixinmethod
    def get_SupportedMethodIds(self: win32more.Windows.ApplicationModel.Payments.IPaymentMethodData) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_JsonData(self: win32more.Windows.ApplicationModel.Payments.IPaymentMethodData) -> WinRT_String: ...
    JsonData = property(get_JsonData, None)
    SupportedMethodIds = property(get_SupportedMethodIds, None)
class PaymentOptionPresence(Enum, Int32):
    None_ = 0
    Optional = 1
    Required = 2
class PaymentOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentOptions
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Payments.PaymentOptions: ...
    @winrt_mixinmethod
    def get_RequestPayerEmail(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions) -> win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence: ...
    @winrt_mixinmethod
    def put_RequestPayerEmail(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions, value: win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence) -> Void: ...
    @winrt_mixinmethod
    def get_RequestPayerName(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions) -> win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence: ...
    @winrt_mixinmethod
    def put_RequestPayerName(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions, value: win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence) -> Void: ...
    @winrt_mixinmethod
    def get_RequestPayerPhoneNumber(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions) -> win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence: ...
    @winrt_mixinmethod
    def put_RequestPayerPhoneNumber(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions, value: win32more.Windows.ApplicationModel.Payments.PaymentOptionPresence) -> Void: ...
    @winrt_mixinmethod
    def get_RequestShipping(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_RequestShipping(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ShippingType(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingType: ...
    @winrt_mixinmethod
    def put_ShippingType(self: win32more.Windows.ApplicationModel.Payments.IPaymentOptions, value: win32more.Windows.ApplicationModel.Payments.PaymentShippingType) -> Void: ...
    RequestPayerEmail = property(get_RequestPayerEmail, put_RequestPayerEmail)
    RequestPayerName = property(get_RequestPayerName, put_RequestPayerName)
    RequestPayerPhoneNumber = property(get_RequestPayerPhoneNumber, put_RequestPayerPhoneNumber)
    RequestShipping = property(get_RequestShipping, put_RequestShipping)
    ShippingType = property(get_ShippingType, put_ShippingType)
class PaymentRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentRequest
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentRequest'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentRequest.Create(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentRequest.CreateWithMerchantInfo(*args))
        elif len(args) == 4:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentRequest.CreateWithMerchantInfoAndOptions(*args))
        elif len(args) == 5:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentRequest.CreateWithMerchantInfoOptionsAndId(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentRequestFactory, details: win32more.Windows.ApplicationModel.Payments.PaymentDetails, methodData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentMethodData]) -> win32more.Windows.ApplicationModel.Payments.PaymentRequest: ...
    @winrt_factorymethod
    def CreateWithMerchantInfo(cls: win32more.Windows.ApplicationModel.Payments.IPaymentRequestFactory, details: win32more.Windows.ApplicationModel.Payments.PaymentDetails, methodData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentMethodData], merchantInfo: win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo) -> win32more.Windows.ApplicationModel.Payments.PaymentRequest: ...
    @winrt_factorymethod
    def CreateWithMerchantInfoAndOptions(cls: win32more.Windows.ApplicationModel.Payments.IPaymentRequestFactory, details: win32more.Windows.ApplicationModel.Payments.PaymentDetails, methodData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentMethodData], merchantInfo: win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo, options: win32more.Windows.ApplicationModel.Payments.PaymentOptions) -> win32more.Windows.ApplicationModel.Payments.PaymentRequest: ...
    @winrt_factorymethod
    def CreateWithMerchantInfoOptionsAndId(cls: win32more.Windows.ApplicationModel.Payments.IPaymentRequestFactory2, details: win32more.Windows.ApplicationModel.Payments.PaymentDetails, methodData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.ApplicationModel.Payments.PaymentMethodData], merchantInfo: win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo, options: win32more.Windows.ApplicationModel.Payments.PaymentOptions, id: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentRequest: ...
    @winrt_mixinmethod
    def get_MerchantInfo(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequest) -> win32more.Windows.ApplicationModel.Payments.PaymentMerchantInfo: ...
    @winrt_mixinmethod
    def get_Details(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequest) -> win32more.Windows.ApplicationModel.Payments.PaymentDetails: ...
    @winrt_mixinmethod
    def get_MethodData(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequest) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Payments.PaymentMethodData]: ...
    @winrt_mixinmethod
    def get_Options(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequest) -> win32more.Windows.ApplicationModel.Payments.PaymentOptions: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequest2) -> WinRT_String: ...
    Details = property(get_Details, None)
    Id = property(get_Id, None)
    MerchantInfo = property(get_MerchantInfo, None)
    MethodData = property(get_MethodData, None)
    Options = property(get_Options, None)
class PaymentRequestChangeKind(Enum, Int32):
    ShippingOption = 0
    ShippingAddress = 1
class PaymentRequestChangedArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedArgs
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentRequestChangedArgs'
    @winrt_mixinmethod
    def get_ChangeKind(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedArgs) -> win32more.Windows.ApplicationModel.Payments.PaymentRequestChangeKind: ...
    @winrt_mixinmethod
    def get_ShippingAddress(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedArgs) -> win32more.Windows.ApplicationModel.Payments.PaymentAddress: ...
    @winrt_mixinmethod
    def get_SelectedShippingOption(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedArgs) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
    @winrt_mixinmethod
    def Acknowledge(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedArgs, changeResult: win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedResult) -> Void: ...
    ChangeKind = property(get_ChangeKind, None)
    SelectedShippingOption = property(get_SelectedShippingOption, None)
    ShippingAddress = property(get_ShippingAddress, None)
class PaymentRequestChangedHandler(MulticastDelegate):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5078b9e1-f398-4f2c-a27e-94d371cf6c7d}')
    @winrt_commethod(3)
    def Invoke(self, paymentRequest: win32more.Windows.ApplicationModel.Payments.PaymentRequest, args: win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedArgs) -> Void: ...
class PaymentRequestChangedResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedResult
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentRequestChangedResult'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedResult.Create(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedResult.CreateWithPaymentDetails(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedResultFactory, changeAcceptedByMerchant: Boolean) -> win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedResult: ...
    @winrt_factorymethod
    def CreateWithPaymentDetails(cls: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedResultFactory, changeAcceptedByMerchant: Boolean, updatedPaymentDetails: win32more.Windows.ApplicationModel.Payments.PaymentDetails) -> win32more.Windows.ApplicationModel.Payments.PaymentRequestChangedResult: ...
    @winrt_mixinmethod
    def get_ChangeAcceptedByMerchant(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedResult) -> Boolean: ...
    @winrt_mixinmethod
    def put_ChangeAcceptedByMerchant(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedResult, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Message(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedResult) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Message(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedResult, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_UpdatedPaymentDetails(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedResult) -> win32more.Windows.ApplicationModel.Payments.PaymentDetails: ...
    @winrt_mixinmethod
    def put_UpdatedPaymentDetails(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestChangedResult, value: win32more.Windows.ApplicationModel.Payments.PaymentDetails) -> Void: ...
    ChangeAcceptedByMerchant = property(get_ChangeAcceptedByMerchant, put_ChangeAcceptedByMerchant)
    Message = property(get_Message, put_Message)
    UpdatedPaymentDetails = property(get_UpdatedPaymentDetails, put_UpdatedPaymentDetails)
class PaymentRequestCompletionStatus(Enum, Int32):
    Succeeded = 0
    Failed = 1
    Unknown = 2
class PaymentRequestStatus(Enum, Int32):
    Succeeded = 0
    Failed = 1
    Canceled = 2
class PaymentRequestSubmitResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentRequestSubmitResult
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentRequestSubmitResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestSubmitResult) -> win32more.Windows.ApplicationModel.Payments.PaymentRequestStatus: ...
    @winrt_mixinmethod
    def get_Response(self: win32more.Windows.ApplicationModel.Payments.IPaymentRequestSubmitResult) -> win32more.Windows.ApplicationModel.Payments.PaymentResponse: ...
    Response = property(get_Response, None)
    Status = property(get_Status, None)
class PaymentResponse(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentResponse
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentResponse'
    @winrt_mixinmethod
    def get_PaymentToken(self: win32more.Windows.ApplicationModel.Payments.IPaymentResponse) -> win32more.Windows.ApplicationModel.Payments.PaymentToken: ...
    @winrt_mixinmethod
    def get_ShippingOption(self: win32more.Windows.ApplicationModel.Payments.IPaymentResponse) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
    @winrt_mixinmethod
    def get_ShippingAddress(self: win32more.Windows.ApplicationModel.Payments.IPaymentResponse) -> win32more.Windows.ApplicationModel.Payments.PaymentAddress: ...
    @winrt_mixinmethod
    def get_PayerEmail(self: win32more.Windows.ApplicationModel.Payments.IPaymentResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_PayerName(self: win32more.Windows.ApplicationModel.Payments.IPaymentResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_PayerPhoneNumber(self: win32more.Windows.ApplicationModel.Payments.IPaymentResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def CompleteAsync(self: win32more.Windows.ApplicationModel.Payments.IPaymentResponse, status: win32more.Windows.ApplicationModel.Payments.PaymentRequestCompletionStatus) -> win32more.Windows.Foundation.IAsyncAction: ...
    PayerEmail = property(get_PayerEmail, None)
    PayerName = property(get_PayerName, None)
    PayerPhoneNumber = property(get_PayerPhoneNumber, None)
    PaymentToken = property(get_PaymentToken, None)
    ShippingAddress = property(get_ShippingAddress, None)
    ShippingOption = property(get_ShippingOption, None)
class PaymentShippingOption(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOption
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentShippingOption'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentShippingOption.Create(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentShippingOption.CreateWithSelected(*args))
        elif len(args) == 4:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentShippingOption.CreateWithSelectedAndTag(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOptionFactory, label: WinRT_String, amount: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
    @winrt_factorymethod
    def CreateWithSelected(cls: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOptionFactory, label: WinRT_String, amount: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount, selected: Boolean) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
    @winrt_factorymethod
    def CreateWithSelectedAndTag(cls: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOptionFactory, label: WinRT_String, amount: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount, selected: Boolean, tag: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentShippingOption: ...
    @winrt_mixinmethod
    def get_Label(self: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOption) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Label(self: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOption, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Amount(self: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOption) -> win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount: ...
    @winrt_mixinmethod
    def put_Amount(self: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOption, value: win32more.Windows.ApplicationModel.Payments.PaymentCurrencyAmount) -> Void: ...
    @winrt_mixinmethod
    def get_Tag(self: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOption) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Tag(self: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOption, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsSelected(self: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOption) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSelected(self: win32more.Windows.ApplicationModel.Payments.IPaymentShippingOption, value: Boolean) -> Void: ...
    Amount = property(get_Amount, put_Amount)
    IsSelected = property(get_IsSelected, put_IsSelected)
    Label = property(get_Label, put_Label)
    Tag = property(get_Tag, put_Tag)
class PaymentShippingType(Enum, Int32):
    Shipping = 0
    Delivery = 1
    Pickup = 2
class PaymentToken(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Payments.IPaymentToken
    _classid_ = 'Windows.ApplicationModel.Payments.PaymentToken'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentToken.Create(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Payments.PaymentToken.CreateWithJsonDetails(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def Create(cls: win32more.Windows.ApplicationModel.Payments.IPaymentTokenFactory, paymentMethodId: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentToken: ...
    @winrt_factorymethod
    def CreateWithJsonDetails(cls: win32more.Windows.ApplicationModel.Payments.IPaymentTokenFactory, paymentMethodId: WinRT_String, jsonDetails: WinRT_String) -> win32more.Windows.ApplicationModel.Payments.PaymentToken: ...
    @winrt_mixinmethod
    def get_PaymentMethodId(self: win32more.Windows.ApplicationModel.Payments.IPaymentToken) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_JsonDetails(self: win32more.Windows.ApplicationModel.Payments.IPaymentToken) -> WinRT_String: ...
    JsonDetails = property(get_JsonDetails, None)
    PaymentMethodId = property(get_PaymentMethodId, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Media.Audio
import win32more.Windows.Win32.Media.Audio.Apo
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.UI.Shell.PropertiesSystem
class APOInitBaseStruct(Structure):
    cbSize: UInt32
    clsid: Guid
class APOInitSystemEffects(Structure):
    APOInit: win32more.Windows.Win32.Media.Audio.Apo.APOInitBaseStruct
    pAPOEndpointProperties: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore
    pAPOSystemEffectsProperties: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore
    pReserved: VoidPtr
    pDeviceCollection: win32more.Windows.Win32.Media.Audio.IMMDeviceCollection
class APOInitSystemEffects2(Structure):
    APOInit: win32more.Windows.Win32.Media.Audio.Apo.APOInitBaseStruct
    pAPOEndpointProperties: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore
    pAPOSystemEffectsProperties: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore
    pReserved: VoidPtr
    pDeviceCollection: win32more.Windows.Win32.Media.Audio.IMMDeviceCollection
    nSoftwareIoDeviceInCollection: UInt32
    nSoftwareIoConnectorIndex: UInt32
    AudioProcessingMode: Guid
    InitializeForDiscoveryOnly: win32more.Windows.Win32.Foundation.BOOL
class APOInitSystemEffects3(Structure):
    APOInit: win32more.Windows.Win32.Media.Audio.Apo.APOInitBaseStruct
    pAPOEndpointProperties: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore
    pServiceProvider: win32more.Windows.Win32.System.Com.IServiceProvider
    pDeviceCollection: win32more.Windows.Win32.Media.Audio.IMMDeviceCollection
    nSoftwareIoDeviceInCollection: UInt32
    nSoftwareIoConnectorIndex: UInt32
    AudioProcessingMode: Guid
    InitializeForDiscoveryOnly: win32more.Windows.Win32.Foundation.BOOL
APO_BUFFER_FLAGS = Int32
BUFFER_INVALID: win32more.Windows.Win32.Media.Audio.Apo.APO_BUFFER_FLAGS = 0
BUFFER_VALID: win32more.Windows.Win32.Media.Audio.Apo.APO_BUFFER_FLAGS = 1
BUFFER_SILENT: win32more.Windows.Win32.Media.Audio.Apo.APO_BUFFER_FLAGS = 2
APO_CONNECTION_BUFFER_TYPE = Int32
APO_CONNECTION_BUFFER_TYPE_ALLOCATED: win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_BUFFER_TYPE = 0
APO_CONNECTION_BUFFER_TYPE_EXTERNAL: win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_BUFFER_TYPE = 1
APO_CONNECTION_BUFFER_TYPE_DEPENDANT: win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_BUFFER_TYPE = 2
class APO_CONNECTION_DESCRIPTOR(Structure):
    Type: win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_BUFFER_TYPE
    pBuffer: UIntPtr
    u32MaxFrameCount: UInt32
    pFormat: win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType
    u32Signature: UInt32
class APO_CONNECTION_PROPERTY(Structure):
    pBuffer: UIntPtr
    u32ValidFrameCount: UInt32
    u32BufferFlags: win32more.Windows.Win32.Media.Audio.Apo.APO_BUFFER_FLAGS
    u32Signature: UInt32
class APO_CONNECTION_PROPERTY_V2(Structure):
    property: win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_PROPERTY
    u64QPCTime: UInt64
APO_FLAG = Int32
APO_FLAG_NONE: win32more.Windows.Win32.Media.Audio.Apo.APO_FLAG = 0
APO_FLAG_INPLACE: win32more.Windows.Win32.Media.Audio.Apo.APO_FLAG = 1
APO_FLAG_SAMPLESPERFRAME_MUST_MATCH: win32more.Windows.Win32.Media.Audio.Apo.APO_FLAG = 2
APO_FLAG_FRAMESPERSECOND_MUST_MATCH: win32more.Windows.Win32.Media.Audio.Apo.APO_FLAG = 4
APO_FLAG_BITSPERSAMPLE_MUST_MATCH: win32more.Windows.Win32.Media.Audio.Apo.APO_FLAG = 8
APO_FLAG_MIXER: win32more.Windows.Win32.Media.Audio.Apo.APO_FLAG = 16
APO_FLAG_DEFAULT: win32more.Windows.Win32.Media.Audio.Apo.APO_FLAG = 14
APO_LOG_LEVEL = Int32
APO_LOG_LEVEL_ALWAYS: win32more.Windows.Win32.Media.Audio.Apo.APO_LOG_LEVEL = 0
APO_LOG_LEVEL_CRITICAL: win32more.Windows.Win32.Media.Audio.Apo.APO_LOG_LEVEL = 1
APO_LOG_LEVEL_ERROR: win32more.Windows.Win32.Media.Audio.Apo.APO_LOG_LEVEL = 2
APO_LOG_LEVEL_WARNING: win32more.Windows.Win32.Media.Audio.Apo.APO_LOG_LEVEL = 3
APO_LOG_LEVEL_INFO: win32more.Windows.Win32.Media.Audio.Apo.APO_LOG_LEVEL = 4
APO_LOG_LEVEL_VERBOSE: win32more.Windows.Win32.Media.Audio.Apo.APO_LOG_LEVEL = 5
class APO_NOTIFICATION(Structure):
    type: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        audioEndpointVolumeChange: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_ENDPOINT_VOLUME_CHANGE_NOTIFICATION
        audioEndpointPropertyChange: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_ENDPOINT_PROPERTY_CHANGE_NOTIFICATION
        audioSystemEffectsPropertyChange: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_SYSTEMEFFECTS_PROPERTY_CHANGE_NOTIFICATION
        audioEndpointVolumeChange2: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_ENDPOINT_VOLUME_CHANGE_NOTIFICATION2
        deviceOrientation: win32more.Windows.Win32.Media.Audio.Apo.DEVICE_ORIENTATION_TYPE
        audioMicrophoneBoostChange: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_MICROPHONE_BOOST_NOTIFICATION
class APO_NOTIFICATION_DESCRIPTOR(Structure):
    type: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        audioEndpointVolume: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_ENDPOINT_VOLUME_APO_NOTIFICATION_DESCRIPTOR
        audioEndpointPropertyChange: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_ENDPOINT_PROPERTY_CHANGE_APO_NOTIFICATION_DESCRIPTOR
        audioSystemEffectsPropertyChange: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_SYSTEMEFFECTS_PROPERTY_CHANGE_APO_NOTIFICATION_DESCRIPTOR
        audioMicrophoneBoost: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_MICROPHONE_BOOST_APO_NOTIFICATION_DESCRIPTOR
APO_NOTIFICATION_TYPE = Int32
APO_NOTIFICATION_TYPE_NONE: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE = 0
APO_NOTIFICATION_TYPE_ENDPOINT_VOLUME: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE = 1
APO_NOTIFICATION_TYPE_ENDPOINT_PROPERTY_CHANGE: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE = 2
APO_NOTIFICATION_TYPE_SYSTEM_EFFECTS_PROPERTY_CHANGE: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE = 3
APO_NOTIFICATION_TYPE_ENDPOINT_VOLUME2: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE = 4
APO_NOTIFICATION_TYPE_DEVICE_ORIENTATION: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE = 5
APO_NOTIFICATION_TYPE_MICROPHONE_BOOST: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE = 6
class APO_REG_PROPERTIES(Structure):
    clsid: Guid
    Flags: win32more.Windows.Win32.Media.Audio.Apo.APO_FLAG
    szFriendlyName: Char * 256
    szCopyrightInfo: Char * 256
    u32MajorVersion: UInt32
    u32MinorVersion: UInt32
    u32MinInputConnections: UInt32
    u32MaxInputConnections: UInt32
    u32MinOutputConnections: UInt32
    u32MaxOutputConnections: UInt32
    u32MaxInstances: UInt32
    u32NumAPOInterfaces: UInt32
    iidAPOInterfaceList: Guid * 1
class AUDIO_ENDPOINT_PROPERTY_CHANGE_APO_NOTIFICATION_DESCRIPTOR(Structure):
    device: win32more.Windows.Win32.Media.Audio.IMMDevice
class AUDIO_ENDPOINT_PROPERTY_CHANGE_NOTIFICATION(Structure):
    endpoint: win32more.Windows.Win32.Media.Audio.IMMDevice
    propertyStore: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore
    propertyKey: win32more.Windows.Win32.Foundation.PROPERTYKEY
class AUDIO_ENDPOINT_VOLUME_APO_NOTIFICATION_DESCRIPTOR(Structure):
    device: win32more.Windows.Win32.Media.Audio.IMMDevice
class AUDIO_ENDPOINT_VOLUME_CHANGE_NOTIFICATION(Structure):
    endpoint: win32more.Windows.Win32.Media.Audio.IMMDevice
    volume: POINTER(win32more.Windows.Win32.Media.Audio.AUDIO_VOLUME_NOTIFICATION_DATA)
class AUDIO_ENDPOINT_VOLUME_CHANGE_NOTIFICATION2(Structure):
    endpoint: win32more.Windows.Win32.Media.Audio.IMMDevice
    volume: POINTER(win32more.Windows.Win32.Media.Audio.Apo.AUDIO_VOLUME_NOTIFICATION_DATA2)
AUDIO_FLOW_TYPE = Int32
AUDIO_FLOW_PULL: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_FLOW_TYPE = 0
AUDIO_FLOW_PUSH: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_FLOW_TYPE = 1
class AUDIO_MICROPHONE_BOOST_APO_NOTIFICATION_DESCRIPTOR(Structure):
    device: win32more.Windows.Win32.Media.Audio.IMMDevice
class AUDIO_MICROPHONE_BOOST_NOTIFICATION(Structure):
    endpoint: win32more.Windows.Win32.Media.Audio.IMMDevice
    eventContext: Guid
    microphoneBoostEnabled: win32more.Windows.Win32.Foundation.BOOL
    levelInDb: Single
    levelMinInDb: Single
    levelMaxInDb: Single
    levelStepInDb: Single
    muteSupported: win32more.Windows.Win32.Foundation.BOOL
    mute: win32more.Windows.Win32.Foundation.BOOL
class AUDIO_SYSTEMEFFECT(Structure):
    id: Guid
    canSetState: win32more.Windows.Win32.Foundation.BOOL
    state: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_SYSTEMEFFECT_STATE
class AUDIO_SYSTEMEFFECTS_PROPERTY_CHANGE_APO_NOTIFICATION_DESCRIPTOR(Structure):
    device: win32more.Windows.Win32.Media.Audio.IMMDevice
    propertyStoreContext: Guid
class AUDIO_SYSTEMEFFECTS_PROPERTY_CHANGE_NOTIFICATION(Structure):
    endpoint: win32more.Windows.Win32.Media.Audio.IMMDevice
    propertyStoreContext: Guid
    propertyStoreType: win32more.Windows.Win32.Media.Audio.AUDIO_SYSTEMEFFECTS_PROPERTYSTORE_TYPE
    propertyStore: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore
    propertyKey: win32more.Windows.Win32.Foundation.PROPERTYKEY
AUDIO_SYSTEMEFFECT_STATE = Int32
AUDIO_SYSTEMEFFECT_STATE_OFF: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_SYSTEMEFFECT_STATE = 0
AUDIO_SYSTEMEFFECT_STATE_ON: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_SYSTEMEFFECT_STATE = 1
class AUDIO_VOLUME_NOTIFICATION_DATA2(Structure):
    notificationData: POINTER(win32more.Windows.Win32.Media.Audio.AUDIO_VOLUME_NOTIFICATION_DATA)
    masterVolumeInDb: Single
    volumeMinInDb: Single
    volumeMaxInDb: Single
    volumeIncrementInDb: Single
    step: UInt32
    stepCount: UInt32
    channelVolumesInDb: Single * 1
APOERR_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2005073919
APOERR_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2005073918
APOERR_FORMAT_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2005073917
APOERR_INVALID_APO_CLSID: win32more.Windows.Win32.Foundation.HRESULT = -2005073916
APOERR_BUFFERS_OVERLAP: win32more.Windows.Win32.Foundation.HRESULT = -2005073915
APOERR_ALREADY_UNLOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2005073914
APOERR_NUM_CONNECTIONS_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2005073913
APOERR_INVALID_OUTPUT_MAXFRAMECOUNT: win32more.Windows.Win32.Foundation.HRESULT = -2005073912
APOERR_INVALID_CONNECTION_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2005073911
APOERR_APO_LOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2005073910
APOERR_INVALID_COEFFCOUNT: win32more.Windows.Win32.Foundation.HRESULT = -2005073909
APOERR_INVALID_COEFFICIENT: win32more.Windows.Win32.Foundation.HRESULT = -2005073908
APOERR_INVALID_CURVE_PARAM: win32more.Windows.Win32.Foundation.HRESULT = -2005073907
APOERR_INVALID_INPUTID: win32more.Windows.Win32.Foundation.HRESULT = -2005073906
AUDIO_MIN_FRAMERATE: Double = 10
AUDIO_MAX_FRAMERATE: Double = 384000
AUDIO_MIN_CHANNELS: UInt32 = 1
AUDIO_MAX_CHANNELS: UInt32 = 4096
PKEY_FX_Association: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=0)
PKEY_FX_PreMixEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=1)
PKEY_FX_PostMixEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=2)
PKEY_FX_UserInterfaceClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=3)
PKEY_FX_FriendlyName: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=4)
PKEY_FX_StreamEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=5)
PKEY_FX_ModeEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=6)
PKEY_FX_EndpointEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=7)
PKEY_FX_KeywordDetector_StreamEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=8)
PKEY_FX_KeywordDetector_ModeEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=9)
PKEY_FX_KeywordDetector_EndpointEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=10)
PKEY_FX_Offload_StreamEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=11)
PKEY_FX_Offload_ModeEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=12)
PKEY_CompositeFX_StreamEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=13)
PKEY_CompositeFX_ModeEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=14)
PKEY_CompositeFX_EndpointEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=15)
PKEY_CompositeFX_KeywordDetector_StreamEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=16)
PKEY_CompositeFX_KeywordDetector_ModeEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=17)
PKEY_CompositeFX_KeywordDetector_EndpointEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=18)
PKEY_CompositeFX_Offload_StreamEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=19)
PKEY_CompositeFX_Offload_ModeEffectClsid: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=20)
PKEY_FX_SupportAppLauncher: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=21)
PKEY_FX_SupportedFormats: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=22)
PKEY_FX_Enumerator: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=23)
PKEY_FX_VersionMajor: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=24)
PKEY_FX_VersionMinor: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=25)
PKEY_FX_Author: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=26)
PKEY_FX_ObjectId: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=27)
PKEY_FX_State: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=28)
PKEY_FX_EffectPackSchema_Version: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=29)
PKEY_FX_ApplyToBluetooth: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=30)
PKEY_FX_ApplyToUsb: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=31)
PKEY_FX_ApplyToRender: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=32)
PKEY_FX_ApplyToCapture: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d04e05a6-594b-4fb6-a80d-01af5eed7d1d}'), pid=33)
PKEY_SFX_ProcessingModes_Supported_For_Streaming: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d3993a3f-99c2-4402-b5ec-a92a0367664b}'), pid=5)
PKEY_MFX_ProcessingModes_Supported_For_Streaming: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d3993a3f-99c2-4402-b5ec-a92a0367664b}'), pid=6)
PKEY_EFX_ProcessingModes_Supported_For_Streaming: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d3993a3f-99c2-4402-b5ec-a92a0367664b}'), pid=7)
PKEY_SFX_KeywordDetector_ProcessingModes_Supported_For_Streaming: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d3993a3f-99c2-4402-b5ec-a92a0367664b}'), pid=8)
PKEY_MFX_KeywordDetector_ProcessingModes_Supported_For_Streaming: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d3993a3f-99c2-4402-b5ec-a92a0367664b}'), pid=9)
PKEY_EFX_KeywordDetector_ProcessingModes_Supported_For_Streaming: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d3993a3f-99c2-4402-b5ec-a92a0367664b}'), pid=10)
PKEY_SFX_Offload_ProcessingModes_Supported_For_Streaming: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d3993a3f-99c2-4402-b5ec-a92a0367664b}'), pid=11)
PKEY_MFX_Offload_ProcessingModes_Supported_For_Streaming: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d3993a3f-99c2-4402-b5ec-a92a0367664b}'), pid=12)
PKEY_APO_SWFallback_ProcessingModes: win32more.Windows.Win32.Foundation.PROPERTYKEY = ConstantLazyLoader(fmtid=Guid('{d3993a3f-99c2-4402-b5ec-a92a0367664b}'), pid=13)
PKEY_FX_EffectPack_Schema_V1: Guid = Guid('{7abf23d9-727e-4d0b-86a3-dd501d260001}')
SID_AudioProcessingObjectRTQueue: Guid = Guid('{458c1a1f-6899-4c12-99ac-e2e6ac253104}')
SID_AudioProcessingObjectLoggingService: Guid = Guid('{8b8008af-09f9-456e-a173-bdb58499bce7}')
AUDIOMEDIATYPE_EQUAL_FORMAT_TYPES: UInt32 = 2
AUDIOMEDIATYPE_EQUAL_FORMAT_DATA: UInt32 = 4
AUDIOMEDIATYPE_EQUAL_FORMAT_USER_DATA: UInt32 = 8
class AudioFXExtensionParams(Structure):
    AddPageParam: win32more.Windows.Win32.Foundation.LPARAM
    pwstrEndpointID: win32more.Windows.Win32.Foundation.PWSTR
    pFxProperties: win32more.Windows.Win32.UI.Shell.PropertiesSystem.IPropertyStore
DEVICE_ORIENTATION_TYPE = Int32
DEVICE_NOT_ROTATED: win32more.Windows.Win32.Media.Audio.Apo.DEVICE_ORIENTATION_TYPE = 0
DEVICE_ROTATED_90_DEGREES_CLOCKWISE: win32more.Windows.Win32.Media.Audio.Apo.DEVICE_ORIENTATION_TYPE = 1
DEVICE_ROTATED_180_DEGREES_CLOCKWISE: win32more.Windows.Win32.Media.Audio.Apo.DEVICE_ORIENTATION_TYPE = 2
DEVICE_ROTATED_270_DEGREES_CLOCKWISE: win32more.Windows.Win32.Media.Audio.Apo.DEVICE_ORIENTATION_TYPE = 3
EAudioConstriction = Int32
eAudioConstrictionOff: win32more.Windows.Win32.Media.Audio.Apo.EAudioConstriction = 0
eAudioConstriction48_16: win32more.Windows.Win32.Media.Audio.Apo.EAudioConstriction = 1
eAudioConstriction44_16: win32more.Windows.Win32.Media.Audio.Apo.EAudioConstriction = 2
eAudioConstriction14_14: win32more.Windows.Win32.Media.Audio.Apo.EAudioConstriction = 3
eAudioConstrictionMute: win32more.Windows.Win32.Media.Audio.Apo.EAudioConstriction = 4
@winfunctype_pointer
def FNAPONOTIFICATIONCALLBACK(pProperties: POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_REG_PROPERTIES), pvRefData: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IApoAcousticEchoCancellation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{25385759-3236-4101-a943-25693dfb5d2d}')
class IApoAuxiliaryInputConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4ceb0aab-fa19-48ed-a857-87771ae1b768}')
    @commethod(3)
    def AddAuxiliaryInput(self, dwInputId: UInt32, cbDataSize: UInt32, pbyData: POINTER(Byte), pInputConnection: POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_DESCRIPTOR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def RemoveAuxiliaryInput(self, dwInputId: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def IsInputFormatSupported(self, pRequestedInputFormat: win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType, ppSupportedInputFormat: POINTER(win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IApoAuxiliaryInputRT(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f851809c-c177-49a0-b1b2-b66f017943ab}')
    @commethod(3)
    def AcceptInput(self, dwInputId: UInt32, pInputConnection: POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_PROPERTY)) -> Void: ...
class IAudioDeviceModulesClient(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{98f37dac-d0b6-49f5-896a-aa4d169a4c48}')
    @commethod(3)
    def SetAudioDeviceModulesManager(self, pAudioDeviceModulesManager: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAudioMediaType(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{4e997f73-b71f-4798-873b-ed7dfcf15b4d}')
    @commethod(3)
    def IsCompressedFormat(self, pfCompressed: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def IsEqual(self, pIAudioType: win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType, pdwFlags: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetAudioFormat(self) -> POINTER(win32more.Windows.Win32.Media.Audio.WAVEFORMATEX): ...
    @commethod(6)
    def GetUncompressedAudioFormat(self, pUncompressedAudioFormat: POINTER(win32more.Windows.Win32.Media.Audio.Apo.UNCOMPRESSEDAUDIOFORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAudioProcessingObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{fd7f2b29-24d0-4b5c-b177-592c39f9ca10}')
    @commethod(3)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetLatency(self, pTime: POINTER(Int64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetRegistrationProperties(self, ppRegProps: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_REG_PROPERTIES))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Initialize(self, cbDataSize: UInt32, pbyData: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def IsInputFormatSupported(self, pOppositeFormat: win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType, pRequestedInputFormat: win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType, ppSupportedInputFormat: POINTER(win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def IsOutputFormatSupported(self, pOppositeFormat: win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType, pRequestedOutputFormat: win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType, ppSupportedOutputFormat: POINTER(win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetInputChannelCount(self, pu32ChannelCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAudioProcessingObjectConfiguration(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0e5ed805-aba6-49c3-8f9a-2b8c889c4fa8}')
    @commethod(3)
    def LockForProcess(self, u32NumInputConnections: UInt32, ppInputConnections: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_DESCRIPTOR)), u32NumOutputConnections: UInt32, ppOutputConnections: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_DESCRIPTOR))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def UnlockForProcess(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAudioProcessingObjectLoggingService(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{698f0107-1745-4708-95a5-d84478a62a65}')
    @commethod(3)
    def ApoLog(self, level: win32more.Windows.Win32.Media.Audio.Apo.APO_LOG_LEVEL, format: win32more.Windows.Win32.Foundation.PWSTR) -> Void: ...
class IAudioProcessingObjectNotifications(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{56b0c76f-02fd-4b21-a52e-9f8219fc86e4}')
    @commethod(3)
    def GetApoNotificationRegistrationInfo(self, apoNotifications: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_DESCRIPTOR)), count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def HandleNotification(self, apoNotification: POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION)) -> Void: ...
class IAudioProcessingObjectNotifications2(ComPtr):
    extends: win32more.Windows.Win32.Media.Audio.Apo.IAudioProcessingObjectNotifications
    _iid_ = Guid('{ca2cfbde-a9d6-4eb0-bc95-c4d026b380f0}')
    @commethod(5)
    def GetApoNotificationRegistrationInfo2(self, maxApoNotificationTypeSupported: win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_TYPE, apoNotifications: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_NOTIFICATION_DESCRIPTOR)), count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAudioProcessingObjectRT(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9e1d6a6d-ddbc-4e95-a4c7-ad64ba37846c}')
    @commethod(3)
    def APOProcess(self, u32NumInputConnections: UInt32, ppInputConnections: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_PROPERTY)), u32NumOutputConnections: UInt32, ppOutputConnections: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.Apo.APO_CONNECTION_PROPERTY))) -> Void: ...
    @commethod(4)
    def CalcInputFrames(self, u32OutputFrameCount: UInt32) -> UInt32: ...
    @commethod(5)
    def CalcOutputFrames(self, u32InputFrameCount: UInt32) -> UInt32: ...
class IAudioProcessingObjectRTQueueService(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{acd65e2f-955b-4b57-b9bf-ac297bb752c9}')
    @commethod(3)
    def GetRealTimeWorkQueue(self, workQueueId: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAudioProcessingObjectVBR(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7ba1db8f-78ad-49cd-9591-f79d80a17c81}')
    @commethod(3)
    def CalcMaxInputFrames(self, u32MaxOutputFrameCount: UInt32, pu32InputFrameCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CalcMaxOutputFrames(self, u32MaxInputFrameCount: UInt32, pu32OutputFrameCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAudioSystemEffects(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5fa00f27-add6-499a-8a9d-6b98521fa75b}')
class IAudioSystemEffects2(ComPtr):
    extends: win32more.Windows.Win32.Media.Audio.Apo.IAudioSystemEffects
    _iid_ = Guid('{bafe99d2-7436-44ce-9e0e-4d89afbfff56}')
    @commethod(3)
    def GetEffectsList(self, ppEffectsIds: POINTER(POINTER(Guid)), pcEffects: POINTER(UInt32), Event: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAudioSystemEffects3(ComPtr):
    extends: win32more.Windows.Win32.Media.Audio.Apo.IAudioSystemEffects2
    _iid_ = Guid('{c58b31cd-fc6a-4255-bc1f-ad29bb0a4a17}')
    @commethod(4)
    def GetControllableSystemEffectsList(self, effects: POINTER(POINTER(win32more.Windows.Win32.Media.Audio.Apo.AUDIO_SYSTEMEFFECT)), numEffects: POINTER(UInt32), event: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetAudioSystemEffectState(self, effectId: Guid, state: win32more.Windows.Win32.Media.Audio.Apo.AUDIO_SYSTEMEFFECT_STATE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAudioSystemEffectsCustomFormats(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b1176e34-bb7f-4f05-bebd-1b18a534e097}')
    @commethod(3)
    def GetFormatCount(self, pcFormats: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFormat(self, nFormat: UInt32, ppFormat: POINTER(win32more.Windows.Win32.Media.Audio.Apo.IAudioMediaType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFormatRepresentation(self, nFormat: UInt32, ppwstrFormatRep: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class UNCOMPRESSEDAUDIOFORMAT(Structure):
    guidFormatType: Guid
    dwSamplesPerFrame: UInt32
    dwBytesPerSampleContainer: UInt32
    dwValidBitsPerSample: UInt32
    fFramesPerSecond: Single
    dwChannelMask: UInt32


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Printing
import win32more.Windows.Win32.Storage.Xps
import win32more.Windows.Win32.Storage.Xps.Printing
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.WinRT
import win32more.Windows.Win32.System.WinRT.Printing
class IPrintDocumentPageSource(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a96bb1db-172e-4667-82b5-ad97a252318f}')
    @commethod(3)
    def GetPreviewPageCollection(self, docPackageTarget: win32more.Windows.Win32.Storage.Xps.Printing.IPrintDocumentPackageTarget, docPageCollection: POINTER(win32more.Windows.Win32.System.WinRT.Printing.IPrintPreviewPageCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MakeDocument(self, printTaskOptions: win32more.Windows.Win32.System.WinRT.IInspectable, docPackageTarget: win32more.Windows.Win32.Storage.Xps.Printing.IPrintDocumentPackageTarget) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintManagerInterop(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _iid_ = Guid('{c5435a42-8d43-4e7b-a68a-ef311e392087}')
    @commethod(6)
    def GetForWindow(self, appWindow: win32more.Windows.Win32.Foundation.HWND, riid: POINTER(Guid), printManager: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ShowPrintUIForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintPreviewPageCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{0b31cc62-d7ec-4747-9d6e-f2537d870f2b}')
    @commethod(3)
    def Paginate(self, currentJobPage: UInt32, printTaskOptions: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MakePage(self, desiredJobPage: UInt32, width: Single, height: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintWorkflowConfigurationNative(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c056be0a-9ee2-450a-9823-964f0006f2bb}')
    @commethod(3)
    def get_PrinterQueue(self, value: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterQueue)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_DriverProperties(self, value: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterPropertyBag)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def get_UserProperties(self, value: POINTER(win32more.Windows.Win32.Graphics.Printing.IPrinterPropertyBag)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintWorkflowObjectModelSourceFileContentNative(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{68c9e477-993e-4052-8ac6-454eff58db9d}')
    @commethod(3)
    def StartXpsOMGeneration(self, receiver: win32more.Windows.Win32.System.WinRT.Printing.IPrintWorkflowXpsReceiver) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def get_ObjectFactory(self, value: POINTER(win32more.Windows.Win32.Storage.Xps.IXpsOMObjectFactory1)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintWorkflowXpsObjectModelTargetPackageNative(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7d96bc74-9b54-4ca1-ad3a-979c3d44ddac}')
    @commethod(3)
    def get_DocumentPackageTarget(self, value: POINTER(win32more.Windows.Win32.Storage.Xps.IXpsDocumentPackageTarget)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintWorkflowXpsReceiver(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{04097374-77b8-47f6-8167-aae29d4cf84b}')
    @commethod(3)
    def SetDocumentSequencePrintTicket(self, documentSequencePrintTicket: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetDocumentSequenceUri(self, documentSequenceUri: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def AddDocumentData(self, documentId: UInt32, documentPrintTicket: win32more.Windows.Win32.System.Com.IStream, documentUri: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def AddPage(self, documentId: UInt32, pageId: UInt32, pageReference: win32more.Windows.Win32.Storage.Xps.IXpsOMPageReference, pageUri: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Close(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrintWorkflowXpsReceiver2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.Printing.IPrintWorkflowXpsReceiver
    _iid_ = Guid('{023bcc0c-dfab-4a61-b074-490c6995580d}')
    @commethod(8)
    def Failed(self, XpsError: win32more.Windows.Win32.Foundation.HRESULT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IPrinting3DManagerInterop(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _iid_ = Guid('{9ca31010-1484-4587-b26b-dddf9f9caecd}')
    @commethod(6)
    def GetForWindow(self, appWindow: win32more.Windows.Win32.Foundation.HWND, riid: POINTER(Guid), printManager: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ShowPrintUIForWindowAsync(self, appWindow: win32more.Windows.Win32.Foundation.HWND, riid: POINTER(Guid), asyncOperation: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)
